import pymel.core as pmc
import os
from lightshader.maya.core import Renderer


def rename(objectType, selected=True):
    activeSelection = []
    if selected:
        activeSelection = pmc.selected()

    if objectType == 'shadingEngine':
        # Renames ShadingEngines based on surfaceShader input connection
        # rename('shadingEngine', selected=False)
        # Works on selected or on all SGs

        def _renameSG(se):
            for shader in se.surfaceShader.connections():
                se.rename('{}SG'.format(shader.name()))

        if selected:
            pmc.undoInfo(openChunk=True)
            for se in activeSelection:
                _renameSG(se)
            pmc.undoInfo(closeChunk=True)


        else:
            # all se's except the default ones
            pmc.undoInfo(openChunk=True)
            for se in pmc.ls(type='shadingEngine'):
                if se.name() in ['initialParticleSE', 'initialShadingGroup']:
                    continue
                _renameSG(se)
            pmc.undoInfo(closeChunk=True)


    if objectType == 'textureInput':

        def _renameTexture(texture):
            attribute = None
            if hasattr(texture, 'filename'):
                attribute = texture.filename
            elif hasattr(texture, 'fileTextureName'):
                attribute = texture.fileTextureName
            textureName = attribute.get()
            if len(textureName) == 0:
                return
            fileName = os.path.split(textureName)[1]
            fileNameBase = os.path.splitext(fileName)[0]

            texture.rename(texture.type() + '_' + fileNameBase)

        if selected:
            pmc.undoInfo(openChunk=True)
            for texture in activeSelection:
                _renameTexture(texture)
            pmc.undoInfo(closeChunk=True)

        else:
            # all se's except the default ones
            textures = pmc.ls(type='file')
            if Renderer.isArnold:
                textures = textures + pmc.ls(type='aiImage')
            elif Renderer.isPrman:
                textures = textures + pmc.ls(type=['PxrTexture', 'PxrPtexture'])

            pmc.undoInfo(openChunk=True)
            for texture in textures:
                _renameTexture(texture)
            pmc.undoInfo(closeChunk=True)

